@@ -12,6 +12,7 @@ import os
 import logging
 from math import exp
 from typing import List
+from tqdm import tqdm
 
 import transformers
 import torch
@@ -70,13 +71,18 @@ class LM:
         self.loss_fct = torch.nn.CrossEntropyLoss(reduction='none')
 
         # GPU setup
+        self.device = self.model.device
         if device_map is None:
             num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
-            if num_gpus > 0:
-                self.model = torch.nn.DataParallel(self.model) if num_gpus > 1 else self.model
+            if num_gpus == 1:
                 self.model.to('cuda')
-        logging.info(f'\t * model is loaded on: {self.model.device}')
+                self.device = self.model.device
+            elif num_gpus > 1:
+                self.model = torch.nn.DataParallel(self.model)
+                self.model.to('cuda')
+                self.device = self.model.module.device
         self.model.eval()
+        logging.info(f'\t * model is loaded on: {self.device}')
 
     def get_perplexity(self, input_texts: str or List, batch: int = None):
         """ Compute the perplexity on recurrent LM.
@@ -95,19 +101,19 @@ class LM:
 
         loss_list = []
         with torch.no_grad():
-            for s, e in batch_id:
+            for s, e in tqdm(batch_id):
 
                 # run model inference
                 if self.max_length is not None:
                     model_inputs = self.tokenizer(input_texts[s:e], max_length=self.max_length, truncation=True, padding='max_length', return_tensors='pt')
                 else:
                     model_inputs = self.tokenizer(input_texts[s:e], truncation=True, padding=True, return_tensors='pt')
-                output = self.model(**{k: v.to(self.model.device) for k, v in model_inputs.items()})
+                output = self.model(**{k: v.to(self.device) for k, v in model_inputs.items()})
 
                 # shift the label sequence for causal inference
                 label = model_inputs['input_ids']
                 label[label == self.tokenizer.pad_token_id] = PAD_TOKEN_LABEL_ID
-                label = torch.concat([label[:, 1:], torch.tensor([[PAD_TOKEN_LABEL_ID] * label.shape[0]]).T], dim=1).to(self.model.device)
+                label = torch.concat([label[:, 1:], torch.tensor([[PAD_TOKEN_LABEL_ID] * label.shape[0]]).T], dim=1).to(self.device)
 
                 # compute loss
                 valid_length = (label != PAD_TOKEN_LABEL_ID).sum(dim=-1)
@@ -119,8 +125,3 @@ class LM:
         # conversion to perplexity
         ppl = [exp(i) for i in loss_list]
         return ppl[0] if single_input else ppl
-
-
-# if __name__ == '__main__':
-#     model = LM("EleutherAI/gpt-neox-20b", device_map="auto", low_cpu_mem_usage=True)
-#     model.get_perplexity("Hello world")
\ No newline at end of file
